boofun.analysis.sparsity
========================

.. automodule:: boofun.analysis.sparsity


   .. rubric:: Functions

   .. autosummary::

      effective_sparsity
      fourier_sparsity
      fourier_sparsity_up_to_constants
      fourier_support
      granularity
      sparsity_by_degree
